@@ -9,4 +9,4 @@ website.
 
 import webbrowser
 
-webbrowser.open('http://www.zachwill.com', new=2)
+webbrowser.open('http://www.importscreencast.com', new=2)
